@@ -144,7 +144,7 @@ sub next {
     $self->assert_open;
     my $name = $self->readdir;
     return unless defined $name;
-    my $io = IO::All->new(File::Spec->catfile($self->pathname, $name));
+    my $io = $self->constructor->(File::Spec->catfile($self->pathname, $name));
     $io->absolute if $self->is_absolute;
     return $io;
 }
@@ -221,10 +221,12 @@ See L<IO::All>.
 
 =head1 AUTHOR
 
-Brian Ingerson <INGY@cpan.org>
+Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
+Copyright (c) 2006. Ingy döt Net. All rights reserved.
+
 Copyright (c) 2004. Brian Ingerson. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
