@@ -14,7 +14,7 @@ sub link {
 
 sub readlink {
     my $self = shift;
-    IO::All->new(CORE::readlink($self->name));
+    $self->constructor->(CORE::readlink($self->name));
 }
 
 sub symlink {
@@ -65,10 +65,12 @@ See L<IO::All>.
 
 =head1 AUTHOR
 
-Brian Ingerson <INGY@cpan.org>
+Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
+Copyright (c) 2006. Ingy döt Net. All rights reserved.
+
 Copyright (c) 2004. Brian Ingerson. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
